@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -125,6 +125,12 @@ class ImportSubcommand(Subcommand):
                "any, then all *default* models will be imported.")
         parser.add_argument('models', nargs='*', metavar='MODEL', help=doc)
 
+        # list models
+        parser.add_argument('--list-all-models', action='store_true',
+                            help="List all available models and exit.")
+        parser.add_argument('--list-default-models', action='store_true',
+                            help="List the default models and exit.")
+
         # make batches
         parser.add_argument('--make-batches', action='store_true',
                             help="If specified, make new Import / Export Batches instead of "
@@ -228,6 +234,15 @@ class ImportSubcommand(Subcommand):
                             "Note that this flag is ignored if --make-batches is specified.")
 
     def run(self, args):
+
+        if args.list_all_models:
+            self.list_all_models(args)
+            return
+
+        if args.list_default_models:
+            self.list_default_models(args)
+            return
+
         log.debug("begin `%s %s` for data models: %s",
                   self.parent_name,
                   self.name,
@@ -271,6 +286,26 @@ class ImportSubcommand(Subcommand):
         else:
             log.info("transaction was committed")
 
+    def list_all_models(self, args):
+        handler = self.get_handler(args=args)
+        self.stdout.write("ALL MODELS:\n")
+        self.stdout.write("==============================\n")
+        defaults = handler.get_default_keys()
+        for key in handler.get_importer_keys():
+            self.stdout.write("{}".format(key))
+            if key in defaults:
+                self.stdout.write(" (*)")
+            self.stdout.write("\n")
+        self.stdout.write("==============================\n")
+        self.stdout.write("(*) means also default\n")
+
+    def list_default_models(self, args):
+        handler = self.get_handler(args=args)
+        self.stdout.write("DEFAULT MODELS:\n")
+        self.stdout.write("==============================\n")
+        for key in handler.get_default_keys():
+            self.stdout.write("{}\n".format(key))
+
 
 # TODO: deprecate / remote this, use ImportFileSubcommand instead
 class ImportFromCSV(ImportSubcommand):
