@@ -27,5 +27,9 @@ DataSync Daemon
 from __future__ import unicode_literals, absolute_import
 
 from .watchers import DataSyncWatcher
-from .consumers import DataSyncConsumer, NewDataSyncImportConsumer, FromRattailConsumer
+from .consumers import (DataSyncConsumer,
+                        DataSyncImportConsumer,
+                        # TODO: deprecate / remove this
+                        NewDataSyncImportConsumer,
+                        FromRattailConsumer)
 from .rattail import FromRattailToRattailExportConsumer, FromRattailToRattailImportConsumer
