@@ -133,6 +133,8 @@ CUSTORDER_ITEM_EVENT_PRICE_CONFIRMED    = 15
 CUSTORDER_ITEM_EVENT_READY              = 20
 # TODO: deprecate / remove this one
 CUSTORDER_ITEM_EVENT_PAID               = CUSTORDER_ITEM_EVENT_READY
+CUSTORDER_ITEM_EVENT_CUSTOMER_RESOLVED  = 21
+CUSTORDER_ITEM_EVENT_PRODUCT_RESOLVED   = 22
 CUSTORDER_ITEM_EVENT_PLACED             = 30
 CUSTORDER_ITEM_EVENT_RECEIVED           = 40
 CUSTORDER_ITEM_EVENT_CONTACTED          = 50
@@ -152,6 +154,8 @@ CUSTORDER_ITEM_EVENT = OrderedDict([
     (CUSTORDER_ITEM_EVENT_PRICE_CONFIRMED,      "price confirmed"),
     (CUSTORDER_ITEM_EVENT_READY,                "order becomes ready to proceed"),
     # (CUSTORDER_ITEM_EVENT_PAID,                 "payment received"),
+    (CUSTORDER_ITEM_EVENT_CUSTOMER_RESOLVED,    "customer resolved"),
+    (CUSTORDER_ITEM_EVENT_PRODUCT_RESOLVED,     "product resolved"),
     (CUSTORDER_ITEM_EVENT_PLACED,               "order placed with vendor"),
     (CUSTORDER_ITEM_EVENT_RECEIVED,             "received from vendor"),
     (CUSTORDER_ITEM_EVENT_CONTACTED,            "customer contacted"),
@@ -242,19 +246,23 @@ MESSAGE_STATUS = {
 
 PENDING_CUSTOMER_STATUS_PENDING         = 1
 PENDING_CUSTOMER_STATUS_READY           = 2
+PENDING_CUSTOMER_STATUS_RESOLVED        = 3
 
 PENDING_CUSTOMER_STATUS = OrderedDict([
     (PENDING_CUSTOMER_STATUS_PENDING,           "pending"),
     (PENDING_CUSTOMER_STATUS_READY,             "ready"),
+    (PENDING_CUSTOMER_STATUS_RESOLVED,          "resolved"),
 ])
 
 
 PENDING_PRODUCT_STATUS_PENDING          = 1
 PENDING_PRODUCT_STATUS_READY            = 2
+PENDING_PRODUCT_STATUS_RESOLVED         = 3
 
 PENDING_PRODUCT_STATUS = OrderedDict([
     (PENDING_PRODUCT_STATUS_PENDING,    "pending"),
     (PENDING_PRODUCT_STATUS_READY,      "ready"),
+    (PENDING_PRODUCT_STATUS_RESOLVED,   "resolved"),
 ])
 
 
