@@ -78,6 +78,38 @@ class tailbone_background_color(Setting):
     name = 'background_color'
 
 
+class tailbone_buefy_version(Setting):
+    """
+    Version of the Buefy component JS library to use for "falafel"
+    based themes.  The minimum should be '0.8.6' or probably even
+    '0.8.13', but feel free to experiment.
+    """
+    namespace = 'tailbone'
+    name = 'buefy_version'
+
+
+class tailbone_sticky_headers(Setting):
+    """
+    Whether table/grid headers should be "sticky" for *ALL* grids.
+    This causes the grid header to remain visible as user scrolls down
+    through the row/record list; however it isn't perfect yet.  Also
+    please note, it will only work with Buefy 0.8.13 or newer.
+    """
+    namespace = 'tailbone'
+    name = 'sticky_headers'
+    data_type = bool
+
+
+class tailbone_vue_version(Setting):
+    """
+    Version of the Vue.js library to use for "falafel" (Buefy) based
+    themes.  The minimum should be '2.6.10' but feel free to
+    experiment.
+    """
+    namespace = 'tailbone'
+    name = 'vue_version'
+
+
 class rattail_single_store(Setting):
     """
     If set, the app should assume there is only one Store record, and that all
